#!/usr/bin/perl
use Math::Trig;
use Cwd 'abs_path';

#########################################################################setpath
$usrname   = "liquan";               #useful when making tmp dir.;
$strum = "/home/liquan/STRUM";
$bindir = "$strum/bin";
$i_tasser = "$strum/I-TASSER4.4";
#$libdir    = "/home/liquan/STLIB";         #template library directory
$libdir    = "$strum/STLIB";
$java_home = "/usr";             #java bin will be located at $java_home/bin/java
$rw="$strum/RW/calRW"; 
$rwplus="$strum/RW/calRWplus";
#------above are zhanglab's softwares 
$hhblits = "$strum/hhsuite-2.0.16-linux-x86_64/bin/hhblits";
$hhdb="$libdir/uniprot20_2015_06/uniprot20_2015_06";
$sift="$strum/sift4.0.3b";
$csh="/bin";
$scwrl="$strum/scwrl4/Scwrl4";
$dfire="$strum/dDFIRE1.1-bin";
$amber= "$strum/amber14";
$foldx="$strum/foldx";
$scikit="$strum/python/lib/python2.7/site-packages";

$datadir   = "/home/$usrname/data/1a2bA"; #at least has 1a2bA.fasta or 1a2bA.pdb
$dssp="$strum/bin/dssp";
$runstyle  = "serial";                       #parallel or serial
#########################################################################setpath

$nres_cut1     = 10;
$nres_cut2     = 1500;
$seq   = "";
$pdb   = "";


my $system    = $^O;
unless (lc($system) eq "linux")
{
    printf("Your operating system $system is unsupported at this time\n");
    printf("Currently only Linux is supported\n");
    exit();
}



################parse arguments
$totarg=0;
foreach $w(@ARGV)
{
	$totarg++;
}

$flagmand[0]=0;
$flagmand[1]=0;
$flagmand[2]=0;
for($i=0;$i<$totarg-1;$i++)
{
	$str1=substr($ARGV[$i+1],0,1);
	if($str1 eq "-")
	{
		next;
	}
	if($ARGV[$i] eq "-datadir")
    	{	
		$datadir=$ARGV[$i+1];
		$flagmand[0]=1;
    	}
	elsif($ARGV[$i] eq "-seq")
	{
		$seq = $ARGV[$i+1];
		$flagmand[1]+=1;	
	}
	elsif($ARGV[$i] eq "-pdb")
	{
		$pdb = $ARGV[$i+1];
		$flagmand[1]+=1;
	}
	if($ARGV[$i] eq "-mutation")
	{
		$mutation = $ARGV[$i+1];
		$flagmand[2]=1;
	}
	elsif($ARGV[$i] eq "-runstyle")
    	{
		$runstyle=$ARGV[$i+1];
    	}
	elsif($ARGV[$i] eq "-libdir")
    	{
		$libdir=$ARGV[$i+1];
    	}
	elsif($ARGV[$i] eq "-i_tasser")
    	{
		$i_tasser=$ARGV[$i+1];
    	}
	elsif($ARGV[$i] eq "-hhblits")
    	{
		$hhblits=$ARGV[$i+1];
    	}
	elsif($ARGV[$i] eq "-hhdb")
    	{
		$hhdb=$ARGV[$i+1];
    	}
	elsif($ARGV[$i] eq "-sift")
    	{
		$sift=$ARGV[$i+1];
    	}
	elsif($ARGV[$i] eq "-csh")
    	{
		$csh=$ARGV[$i+1];
    	}
	elsif($ARGV[$i] eq "-scwrl")
    	{
		$scwrl=$ARGV[$i+1];
    	}
	elsif($ARGV[$i] eq "-dfire")
    	{
		$dfire=$ARGV[$i+1];
    	}
	elsif($ARGV[$i] eq "-amber")
    	{
		$amber=$ARGV[$i+1];
    	}
	elsif($ARGV[$i] eq "-foldx")
    	{
		$foldx=$ARGV[$i+1];
    	}
}


if($flagmand[0]==0)
{
    &print_help();
    print "please set -datadir\n\n";    
    exit();
}
if($flagmand[1]==0)
{
    &print_help();
    print "please set -seq or -pdb\n\n";    
    exit();
}
if($flagmand[2]==0)
{
    &print_help();
    print "please set -mutation\n\n";    
    exit();
}
if($flagmand[1]>1)
{
    &print_help();
    print "please only select one Model: -seq or -pdb\n\n";    
    exit();
}

$wild ='';
$mutant='';
$position=0;
if($mutation =~/^([A-Za-z])([1-9]\d*)([A-Za-z]$)/)
{
	$wild=$1;
	$position=$2;
	$mutant=$3;
}
else
{
	&print_help();
	print "please enter right mutation: Wild Position Mutation.\n eg: -mutation A32R\n\n";
	exit();		
}


$usrname=getlogin() || $ENV{'USER'};


printf "\nYour setting for running I-TASSER is:\n";
printf "-libdir    = $libdir\n";
printf "-datadir   = $datadir\n";
printf "-runstyle  = $runstyle\n";
printf "-seq     = $seq\n";
printf "-pdb     = $pdb\n";
printf "-mutation    = $mutation\n";

$blastdir = "$pkgdir/blast/bin";
$db       = "$libdir/nr/nr";

if(!-s "$db")
{
    print "Your library files are not complete, please download library with the script download_lib.pl\n";
    exit;
}

%ISAA=(
		'A'=>'1',
		'H'=>'1',
		'T'=>'1',
		'R'=>'1',
		'I'=>'1',
		'W'=>'1',
		'N'=>'1',
		'L'=>'1',
		'Y'=>'1',
		'D'=>'1',
		'K'=>'1',
		'V'=>'1',
		'C'=>'1',
		'M'=>'1',
		'Q'=>'1',
		'F'=>'1',
		'E'=>'1',
		'P'=>'1',
		'G'=>'1',
		'S'=>'1',
		);
%AA=(
		'ALA'=>'A', 'ARG'=>'R', 'ASN'=>'N', 'ASP'=>'D', 'CYS'=>'C', 'GLN'=>'Q', 'GLU'=>'E', 'GLY'=>'G',
		'HIS'=>'H', 'ILE'=>'I', 'LEU'=>'L', 'LYS'=>'K', 'MET'=>'M', 'PHE'=>'F', 'PRO'=>'P', 'SER'=>'S',
		'THR'=>'T', 'TRP'=>'W', 'TYR'=>'Y', 'VAL'=>'V');
########################check the input########################
$infile = '';
$type = -1;
$n_ch = 0;
$sequence = '';
$Lmessage = '';
$message = '';
%LCH = ();
$LCH{1} = 0;
@PDBfile  = ();
%ts2      = ();
$n        = -10000;
$ch_old   = '';
$res_old  = '';


if ($seq ne "")
{
	$infile = "$datadir/$seq";
	$type = 0;
}
else
{
	$infile = "$datadir/$pdb";
	$type = 1;
}
@lines=();

if(not -e $infile)
{
	print "\nError: $infile is not exist\n\n";
	exit();
}

open(FIN,"<$infile");
while(my $line=<FIN>)
{
	push(@lines, $line);
}
close(FIN);


if($type == 0)
{
	my $n_ch1=0;
    	$n_ch++;
    	my $nnn=@lines;
    	for(my $i=0; $i<@lines; $i++)
    	{
		my $line=$lines[$i];
		if($line=~/^>/)
        	{	
	    		$n_ch1++;	    
	    		if($n_ch1>1)
	    		{
				last;
	    		}	  
	    		push(@PDBfile, $line);	    
        	}	
		else
		{
	    		$line =~ s/\s+//g;
	    		my @seqline=split(//, $line);
	    		$line="";
	    		foreach my $ch (@seqline)
	    		{
				if(exists $ISAA{$ch})
				{
		    			$line .= $ch;
		    			$sequence .= $ch;
				}
				else
				{
		    			$Lmessage .="LOG: $ch is not a standard amino acid. It was removed automatically.\n";
				}
	    		}
	    		if(length $line >0)	    
	    		{	
				$LCH{$n_ch} += length $line;
				push(@PDBfile, $line);
	    		}
		}	
    	}	

    	if($n_ch1>1)
    	{
		$n_ch=$n_ch1;
    	}	
}
else
{
	foreach my $line(@lines)
	{		
		if($line=~/MODRES\s*\S+\s*(\S+)\s*\S+\s+\S+\s+(\S+)/)
		{
			if(exists $AA{$2})
			{
				$ts2{$1}=$2;
			}
		}
		if($line=~/^ATOM/)
		{
			my $record     = substr($line,0,6);
			my $ch         = substr($line,21,1);
			my $xyz        = substr($line,30,24);
			my $res        = substr($line,22,5);
			my $res_name   = substr($line,17,3);

			if ($n == -10000)
			{
				$n = substr($line,22,4); $n =~s/\s+//g;
				if($n != 1)
				{
					$Lmessage .="LOG: First residue in the structure file is $n and not 1. The residues will be renumbered strating from 1 and all results will be based on new numbering scheme\n"; 
				}
			}
			if($ch ne $ch_old)
			{
				$n_ch++;
				$ch_old=$ch;		
			}
			if($res_old ne $res)
			{
				$LCH{$n_ch}++;
				$res_old=$res;
				if($n_ch < 2)
				{
					$sequence .= $AA{$res_name};
				}
			}
			if($n_ch < 2)
			{
				substr($line, 22, 4) = sprintf "%4d", $LCH{$n_ch};
				if(exists $AA{$res_name})
				{		   
					push(@PDBfile,$line);
				}
				elsif($res_name eq 'MSE')
				{
					substr($line,17,3)  = sprintf "%3s",'MET';
					$Lmessage .="$res_name at $res is not a valid amino acid name. Was converted to MET\n";
					push(@PDBfile,$line);
				}
				elsif($res_name eq 'ASX')
				{
					substr($line,17,3)  = sprintf "%3s",'ASN';
					$Lmessage .="$res_name at $res is not a valid amino acid name. Was converted to ASN\n";
					push(@PDBfile,$line);
				}
				elsif($res_name eq 'GLX')
				{
					substr($line,17,3)  = sprintf "%3s",'GLN';
					$Lmessage .="$res_name at $res is not a valid amino acid name. Was converted to GLN\n";
					push(@PDBfile,$line);
				}
				elsif(exists $ts2{$res_name})
				{
					substr($line,17,3)  = sprintf "%3s",$ts2{$res_name};
					$Lmessage .="$res_name at $res is not a valid amino acid name. Was converted to $ts2{$res_name}\n";
					push(@PDBfile,$line);
				}
				else{$message .="$res_name at $res is not a valid amino acid name. Rename it to standard three letter amino acid code\n";}		
			}	    
		}
		elsif(($line=~/^TER/)||($line=~/^ENDM/))
		{
			$ch_old ='';
		}
	}
}
if($n_ch > 1)
{  
	$Lmessage .='LOG:';
	$Lmessage .="Submitted protein contained multiple chains. Currently, STRUM cannot be used for oligomeric proteins, hence it will use only the first protein chain from the provided file\n\n";   	
}
if($LCH{1} < $nres_cut1)
{	
	$message .='Error: ';	
	$message .="The protein contains less than $nres_cut1 (Lch=$LCH{1}) residues and is too short for obtaining any meaningful prediction using this server.\n\n";	
} 
if($LCH{1} > $nres_cut2)
{
	$message .='Error: ';	$message .="The protein is too large for our server (Lch=$LCH{1}),  maximum length of protein accepted by the server is $nres_cut2. You may want to split the protein into domains and submit individual domains.\n\n";
} 
my $protein_length=$LCH{1};


if($position>$LCH{1})
{
	$message .='Error: ';	
	$message .="The position $position in $mutation is greater than length of the input protein.\n\n";
}

if($wild ne substr($sequence,$position-1,1))
{
	my $res_index=substr($sequence,$position-1,1);
	$message .='Error: ';
	$message .="Amino acid $wild in $mutation doesn't correspond to the $position th residue $res_index of the input protein.\n\n";
}
if($wild eq $mutant)
{
	$message .='Error: ';
	$message .="mutant amino acid $mutant is equal to wild-type amino acid.\n\n";
}


$seqname='';
if($type ==1)
{
	my @array = split(/\./,$pdb);
	$seqname= @array[0];
	open(OUTFASTA,">$datadir/seq.fasta");
	print OUTFASTA ">$pdb\n";
	print OUTFASTA "$sequence\n";
	close(OUTFASTA);


	open(OUTPDB,">$datadir/pdb.pdb");
	foreach my $line(@PDBfile)
	{
		chomp($line);
		print OUTPDB "$line\n";	       
	}
	close(OUTPDB);
	print "\n\nNote: The pudated pdb is $datadir/pdb.pdb\n";
}
else
{
	my @array = split(/\./,$seq);
	$seqname= @array[0];
	open(OUTPDB,">$datadir/seq.fasta");
	foreach my $line(@PDBfile)
	{
		chomp($line);
		print OUTPDB "$line\n";	       
	}
	close(OUTPDB);
	print "\n\nNote: The pudated sequence is $datadir/seq.fasta\n";     
}
if($Lmessage ne '')
{
	print "\n\n$Lmessage";
}
if($message ne '')
{
	print "\n\n$message";
	exit(-1);
}

########################run STRUM########################
$nanosecond=`date +\%N`;#
chomp($nanosecond);#
#$unicode="SM$seqname";            #useful when making tmp dir and setting unique jobname
$unicode="$seqname$nanosecond";            #useful when making tmp dir and setting unique jobname
$tmpdir="/tmp/ST$usrname/$unicode";
`mkdir -p $tmpdir`;
chdir "$tmpdir";
if(!-d "$tmpdir")
{
	printf "Fail make temporary directory $tmpdir\n";
	print "Please make sure the directory /tmp/ is writable for you\n ";
	exit();
}
`cp $datadir/seq.fasta $tmpdir`;
if($type == 1)
{
	`cp $datadir/pdb.pdb $tmpdir`;
}

`$bindir/stdseq.pl $tmpdir $seqname > $datadir/running.log 2>&1`;

if(!(-e "$datadir/$seqname"))
{
	mkdir "$datadir/$seqname";
}
`cp $datadir/seq.fasta $datadir/$seqname/seq.fasta`;

if($type ==0)
{
	########################################run I-TASSER
	print "I-TASSER is running......\n";  	
	`$i_tasser/I-TASSERmod/runI-TASSER.pl -pkgdir $i_tasser -libdir $libdir -java_home $java_home -seqname $unicode -datadir $datadir/$seqname -runstyle $runstyle >> $datadir/running.log 2>&1`; 	
	if(-s "$datadir/$seqname/model1.pdb")
	{
		`cp $datadir/$seqname/model1.pdb $datadir/pdb.pdb`;
		`cp $datadir/pdb.pdb $tmpdir/`;
	}
	else
	{
		print "Structure was not predicted by I-TASSER......\n";
	}
}
else
{
	print "LOMETS is running......\n";  	
	`$i_tasser/I-TASSERmod/runLOMETS.pl -pkgdir $i_tasser -libdir $libdir -java_home $java_home -seqname $unicode -datadir $datadir/$seqname -runstyle $runstyle >> $datadir/running.log 2>&1`;
}


#-------------------sequence-based features------------------->


########################################run hhblits
print "hhblits is running......\n";
`$hhblits -d $hhdb -i $tmpdir/seq1.txt -o $tmpdir/seq.hhr -n 3 -cov 60 -Z 1000 -mact 0 -B 1000 >> $datadir/running.log 2>&1`;
`cp $tmpdir/seq.hhr $datadir/seq.hhr`;

########################################run sift
print "SIFT is running......\n";  	
$mod      =`cat $bindir/SIFTmod`;
$mod =~ s/\!NCBI\!/$i_tasser\/blast\/bin/mg;
$mod =~ s/\!BLIMPS_DIR\!/$sift\/blimps/mg;	
$mod =~ s/\!SIFT_DIR\!/$sift/mg;	
$mod =~ s/\!ROOTF\!/$tmpdir\/seq2.txt/mg;
$mod =~ s/\!LIB\!/$libdir\/nr\/nr/mg;
#$mod =~ s/\!LIB\!/\/nfs\/amino-home\/liquan\/Database\/nr\/nr/mg;   
$mod =~ s/\!SET\!/-/mg;
$mod =~ s/\!VALUE\!/2.75/mg;
$mod =~ s/\!TMPDIR\!/$tmpdir/mg;
$mod =~ s/\!SCRIPT\!/$bindir/mg;
open(QSF1,">$tmpdir/sift.csh");
print QSF1 "$mod";
`chmod a+x $tmpdir/sift.csh`;
`$csh/csh $tmpdir/sift.csh >> $datadir/running.log 2>&1`;
`cp $tmpdir/seq2.txt.query.out $datadir`;

########################################group MSA from SIFT, hhblits and psiblast to calulate a new PSSM
`cp $datadir/$seqname/blast.out $tmpdir`;
`$bindir/Caculate_PSSM.pl $tmpdir >> $datadir/running.log 2>&1`;
`cp $tmpdir/seq.pssm $datadir`;


########################################get secondary structure
print "get the secondary structure......\n";
`cp $datadir/$seqname/seq.ss $datadir`;
`cp $datadir/$seqname/seq.ss $tmpdir`;

########################################get SA, phi and psi
print "get SA, phi and psi......\n";
chdir "$tmpdir";
`$bindir/get_SA_phi_psi.pl $datadir/$seqname $tmpdir $i_tasser $libdir $seqname >> $datadir/running.log 2>&1`;
`cp $tmpdir/seq.exp.sa $datadir/`;
`cp $tmpdir/seq.svr.phi $datadir/`;
`cp $tmpdir/seq.svr.psi $datadir/`;

open(MYFILE,"$datadir/seq.exp.sa") or die "cannot open seq.exp.sa";
$number = grep {!/^\s*$/} <MYFILE>;
if ($number != ($protein_length+1))
{

	die "no or wrong seq.exp.sa is given by get_SA_phi_psi.pl\n";
}
else
{
	print "seq.exp.sa is given by get_SA_phi_psi.pl\n";
}
open(MYFILE,"$datadir/seq.svr.phi") or die "cannot open seq.svr.phi";
$number = grep {!/^\s*$/} <MYFILE>;
if ($number != ($protein_length+1))
{

	die "no or wrong seq.svr.phi and seq.svr.psi are given by get_SA_phi_psi.pl\n";
}
else
{
	print "seq.svr.phi and seq.svr.psi are given by get_SA_phi_psi.pl\n";
}


#-------------------Template-based features------------------->


########################################get weighted average BLUSUM64
print "get weighted average BLUSUM......\n";
`$bindir/WBLUSUM_wt.pl $tmpdir/potential_wt $wild $position $mutant $datadir/$seqname $libdir $i_tasser $dssp >> $datadir/running.log 2>&1`;
`$bindir/WBLUSUM_mt.pl $tmpdir/potential_mt $wild $position $mutant $datadir/$seqname $libdir $i_tasser $dssp >> $datadir/running.log 2>&1`;
`cp $tmpdir/potential_wt/seq_wt.we $datadir/`;
`cp $tmpdir/potential_mt/seq_mt.we $datadir/`;

open(MYFILE,"$datadir/seq_wt.we") or die "cannot open seq_wt.we";
$number = grep {!/^\s*$/} <MYFILE>;
if ($number < 2 )
{

	die "no or wrong seq_wt.we is given by WBLUSUM_wt.pl\n";
}
else
{
	print "seq_wt.we is given by WBLUSUM_wt.pl\n";
}

open(MYFILE,"$datadir/seq_mt.we") or die "cannot open seq_mt.we";
$number = grep {!/^\s*$/} <MYFILE>;
if ($number < 2 )
{

	die "no or wrong seq_mt.we is given by WBLUSUM_mt.pl\n";
}
else
{
	print "seq_mt.we is given by WBLUSUM_mt.pl\n";
}


#-------------------I-TASSER model-based features------------------->


########################################mutant structure is generated
print "Preparing Strucutres for model-based features......\n";
`$bindir/SCWRLPDB_wt.py $seqname $tmpdir $tmpdir/ScwrlPDB_wt $scwrl >> $datadir/running.log 2>&1`;
`$bindir/SCWRLPDB_mt.py $seqname $tmpdir $tmpdir/ScwrlPDB_mt $wild $position $mutant $scwrl >> $datadir/running.log 2>&1`;
$wild_pdb="$seqname.pdb";
$mutant_pdb="$seqname$position$mutant.pdb";
if(-e "$tmpdir/ScwrlPDB_wt/$wild_pdb")
{
	`cp $tmpdir/ScwrlPDB_wt/$wild_pdb $datadir`;
}
else
{
	print "we did not get wild structure through SCWRL......\n";
	exit();
}
if(-e "$tmpdir/ScwrlPDB_mt/$mutant_pdb")
{
	`cp $tmpdir/ScwrlPDB_mt/$mutant_pdb $datadir`;
}
else
{
	print "we did not get wild structure through SCWRL......\n";
	exit();
}


########################################get RW and DFIRE energy
print "RW and DFIRE is running......\n";
`$bindir/RW_DFIRE.pl $seqname $tmpdir/RW $wild $position $mutant $tmpdir $rw $rwplus $dfire >> $datadir/running.log 2>&1`;
`cp $tmpdir/RW/$seqname.we $datadir/RW_DFIRE.en`;
open(MYFILE,"$datadir/RW_DFIRE.en") or die "cannot open RW_DFIRE.en\n";
$number = grep {!/^\s*$/} <MYFILE>;
if ($number < 1 )
{

	die "no or wrong RW_DFIRE.en is given by RW_DFIRE.pl\n";
}


########################################get Amber energy
print "Amber is running......\n";
`$bindir/Amber_wt.pl $seqname $tmpdir/amber_wt $tmpdir/ScwrlPDB_wt $amber >> $datadir/running.log 2>&1`;
`$bindir/Amber_mt.pl $seqname$position$mutant $tmpdir/amber_mt $tmpdir/ScwrlPDB_mt $amber >> $datadir/running.log 2>&1`;
`cp $tmpdir/amber_wt/$seqname*.dat $datadir`;
`cp $tmpdir/amber_mt/$seqname*.dat $datadir`;
open(MYFILE,"$datadir/$seqname\_DECOMP_MMPBSA.dat") or die "we can not get results from amber\n";
$number = grep {!/^\s*$/} <MYFILE>;
if ($number < $protein_length+7 )
{

	die "no or wrong *MMPBSA.dat is given amber\n";
}


########################################get Foldx energy
print "Foldx is running......\n";
`$bindir/Foldx_wt.pl $seqname $tmpdir/foldx_wt $tmpdir/ScwrlPDB_wt $foldx >> $datadir/running.log 2>&1`;
`$bindir/Foldx_mt.pl $seqname$position$mutant $tmpdir/foldx_mt $tmpdir/ScwrlPDB_mt $foldx >> $datadir/running.log 2>&1`;
`cp $tmpdir/foldx_wt/$seqname.stability $datadir`;
`cp $tmpdir/foldx_mt/$seqname$position$mutant.stability $datadir`;
open(MYFILE,"$datadir/$seqname.stability") or die "we can not get results from Foldx\n";
$number = grep {!/^\s*$/} <MYFILE>;
if ($number < 1 )
{

	die "no or wrong $seqname.stability is given by Foldx\n";
}


#-------------------Extrcting features and predicting------------------->

########################################extracting features
print "Extracting features is runing......\n";
$information="$seqname $position $wild $mutant";
`$bindir/Extract_Features.py $information $datadir $datadir >> $datadir/running.log 2>&1`;

########################################predicting ddG
if($type == 1)
{
	`$bindir/Get_ddG.py $bindir/STRUM_NATIVE.pkl $datadir/Features.txt $wild $position $mutant $seqname $datadir/ddG.txt $scikit  >> $datadir/running.log 2>&1`;
}
else
{
	`$bindir/Get_ddG.py $bindir/STRUM_ITASSER.pkl $datadir/Features.txt $wild $position $mutant $seqname $datadir/ddG.txt $scikit  >> $datadir/running.log 2>&1`;
}

if(not -e "$datadir/ddG.txt")
{
	print "\nError: ddG is not generated!\n";
	exit();
}
open(DDG,"<$datadir/ddG.txt");
$ddG_line=<DDG>;
$ddG_line=<DDG>;
@ddG=split(/\t/, $ddG_line);


print "\n";
print "\n";
print "\n";
print "#######################################################################\n";
print "#                           STRUM    Result                           #\n";
print "#                                                                     #\n"; 
print "# protein     position     wild-type     mutant-type     ddG          #\n";
printf "# %-12s%-13s%-14s%-16s%-10.2f   #\n", $seqname, $position,$wild,$mutant,$ddG[4];
print "#                                                                     #\n";
print "# the result is saved in ddG.txt.                                     #\n";
print "#                                                                     #\n";
print "#######################################################################\n";



sub print_help
{
    printf 
	"STRUM USAGE:
=====================
Mandatory arguments:
=====================
./runSTRUM.pl  -datadir datadir -pdb seqname.pdb -mutation mutation
./runSTRUM.pl  -datadir datadir -seq seqname.fasta -mutation mutation


    -datadir:   this is the directory where your input sequence \"proteinname.fasta\" or pdb \"proteinname.pdb\" is located, and the 
                final results should be saved
    -mutation:  the single-point muation information including: the wild-type residue, the position number of the residue that 
                undergoes mutation and the mutant residue, eg, A44T

either-or
    -pdb:       the name of PDB protein code (PDB protein code must be saved in datadir)
    -seq:       the name of protein sequence in raw format and one letter code (the protein sequence code must be saved in 
                datadir)


==================
Optional arguments:
==================
    -runstyle   default value is \"serial\" which means running I-TASSER simulation sequentially, 
                \"parallel\" means running I-TASSER simulations in parallel, distributed on cluster nodes
    
Tips for path setting:
    -libdir:    where the libraries should be saved (all libraries STRUM needed must be saved in a same directory). go to the nr and 
                enter the command \"pwd\", you may get similar message like this /home/liquan/STRUM/ITLIB/nr, then the path is 
                /home/liquan/STRUM/ITLIB
    -STRUM:     go to the runSTRUM.pl folder and enter the command \"pwd\", you may get similar message like this 
                /home/liquan/STRUM, then the path is /home/liquan/STRUM  
    -java_home: enter the command \"which java\", you may get a path like /usr/java/latest/bin/java, then the path is /usr/java/latest
    -i_tasser:  the path of the I-TASSER package. go to the I-TASSERmod folder and enter the command \"pwd\", you may get 
                similar message like this /home/liquan/STRUM/I-TASSER4.4/I-TASSERmod, then the path is /home/liquan/STRUM//I-TASSER4.4
    -hhblits:   the path of HHblits. go to the hhblits folder and enter the command \"pwd\", you may get similar message like this
                /home/liquan/STRUM/hhsuite/bin, then the path is /home/liquan/STRUM/hhsuite/bin/hhblits.
    -hhdb:      the path of the dataset used by hhblits. the simillar path is $libdir/uniprot20_2015_06/uniprot20_2015_06
    -sift:      the path of SIFT. go to the SIFT_for_submitting_fasta_seq.csh folder and enter the command \"pwd\", you may get similar 
                message like this /home/liquan/STRUM/sift/bin, then the path is /home/liquan/STRUM/sift.
    -csh:       enter the command \"which csh\", you may get a path like /bin/csh, then the path is /bin
    -scwrl:     the path of SCWRL4. go to the Scwrl4.ini folder and enter the command \"pwd\", you may get similar message like this
                /home/liquan/STRUM/scwrl4, then the path is /home/liquan/STRUM/scwrl4/Scwrl4
    -dfire:     the path of dDFIRE. go to the dfire.1 folder and enter the command \"pwd\", you may get similar message like this
                /home/liquan/STRUM/dDFIRE1.1-bin, then the path is /home/liquan/STRUM/dDFIRE1.1-bin
    -amber:     the path of AmberTools14. go to the amber.sh folder and enter the command \"pwd\", you may get similar message like this
                /home/liquan/STRUM/amber14, then the path is /home/liquan/STRUM/amber14
    -foldx:     the path of FoldX. go to the foldx3b6 folder and enter the command \"pwd\", you may get similar message like this
                /home/liquan/STRUM/foldx, then the path is /home/liquan/STRUM/foldx

    
    
     We suggest testing your installation first with a short sequence (e.g., about 30 residues) before running production jobs for your proteins.
     An example command for running I-TASSER using a pdb \"1arrA.pdb\" under the folder /home/XXX/STRUM/example

     ./runSTRUM.pl -datadir /home/XXX/STRUM/example -pdb 1arrA.pdb -mutation S35G

";
}
